@@ -7,7 +7,7 @@
 #' @example inst/examples/ex-get_fitting_param_GOF.R
 #' @export
 get_fitting <- function(fit){
-    llply(fit, get_fitting.fFITs) %>% melt_list("flag")
+    lapply(fit, get_fitting.fFITs) %>% melt_list("flag")
 }
 
 #' @rdname get_fitting
@@ -15,6 +15,8 @@ get_fitting <- function(fit){
 #' @importFrom purrr map_dfc
 #' @export
 get_fitting.fFITs <- function(fFITs){
+    models = fFITs$model
+
     t  <- fFITs$data$t
     # fix error: t not in tout
     I  <- match(t, fFITs$tout)
@@ -22,13 +24,14 @@ get_fitting.fFITs <- function(fFITs){
     I  <- I[Ix]
     t  <- t[Ix]
 
-    iters <- length(fFITs$fFIT[[1]]$zs)
-    df <- fFITs$fFIT %>% map(function(x){
-        d_z <- map_dfc(x$zs, ~.[I]) %>% set_colnames(paste0("ziter", 1:iters))
+    iters <- length(models[[1]]$zs)
+    df <- models %>% map(function(x){
+        d_z <- map(x$zs, ~.[I]) %>% as.data.table() %>%
+            set_colnames(paste0("ziter", 1:iters))
         # d_w <- map_dfc(x$ws, ~.) %>% set_colnames(paste0("witer", 1:iters))
         cbind(t, d_z) # , d_w
-    }) %>% melt_list("meth") %>% as.data.table()
-
+    }) %>% melt_list("meth") #%>% as.data.table()
+    
     df <- merge(fFITs$data[Ix], df, id = "t")
     df$t %<>% as.Date(date.origin)
     df
