@@ -15,7 +15,7 @@
 extern void smooth2(void *, void *, void *, void *, void *, void *, void *, void *);
 
 /* .Call calls */
-extern SEXP _phenofit_check_season(SEXP, SEXP, SEXP, SEXP);
+extern SEXP _phenofit_rcpp_season_filter(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _phenofit_sgmat_S(SEXP, SEXP);
 extern SEXP _phenofit_sgmat_B(SEXP);
 extern SEXP _phenofit_sgmat_wB(SEXP, SEXP);
@@ -39,25 +39,24 @@ static const R_CMethodDef CEntries[] = {
 };
 
 static const R_CallMethodDef CallEntries[] = {
-    CALLDEF(_phenofit_check_season, 4),
-    CALLDEF(_phenofit_sgmat_S   , 2),
-    CALLDEF(_phenofit_sgmat_B   , 1),
-    CALLDEF(_phenofit_sgmat_wB  , 2),
+    CALLDEF(_phenofit_rcpp_season_filter, 4),
+    CALLDEF(_phenofit_sgmat_S, 2),
+    CALLDEF(_phenofit_sgmat_B, 1),
+    CALLDEF(_phenofit_sgmat_wB, 2),
     CALLDEF(_phenofit_rcpp_wSG, 4),
-    CALLDEF(_phenofit_rcpp_SG , 3),
-    CALLDEF(_phenofit_rcpp_wTSM  , 6),
-    CALLDEF(_phenofit_movmean   , 4),
+    CALLDEF(_phenofit_rcpp_SG, 3),
+    CALLDEF(_phenofit_rcpp_wTSM, 6),
+    CALLDEF(_phenofit_movmean, 4),
 
     CALLDEF(_phenofit_f_goal_cpp, 7),
-    CALLDEF(_phenofit_clogistic        , 3),
-    CALLDEF(_phenofit_cdoubleLog_Zhang , 3),
-    CALLDEF(_phenofit_cdoubleLog_AG    , 3),
-    CALLDEF(_phenofit_cdoubleLog_Beck  , 3),
+    CALLDEF(_phenofit_clogistic, 3),
+    CALLDEF(_phenofit_cdoubleLog_Zhang, 3),
+    CALLDEF(_phenofit_cdoubleLog_AG, 3),
+    CALLDEF(_phenofit_cdoubleLog_Beck, 3),
     CALLDEF(_phenofit_cdoubleLog_Elmore, 3),
-    CALLDEF(_phenofit_cdoubleLog_Gu    , 3),
-    CALLDEF(_phenofit_cdoubleLog_Klos  , 3),
-    {NULL, NULL, 0}
-};
+    CALLDEF(_phenofit_cdoubleLog_Gu, 3),
+    CALLDEF(_phenofit_cdoubleLog_Klos, 3),
+    {NULL, NULL, 0}};
 
 void R_init_phenofit(DllInfo *dll)
 {
